@@ -1,13 +1,15 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
-from typing import Generic, overload, TypeVar
+from typing import Generic, TypeVar
 
 from .sets import FiniteSet, Setoid
 
-A = TypeVar("A")
-B = TypeVar("B")
-C = TypeVar("C")
+A = TypeVar("A", contravariant=True)
+B = TypeVar("B", covariant=True)
+E1 = TypeVar("E1", contravariant=True)
+E2 = TypeVar("E2")
+E3 = TypeVar("E3", covariant=True)
 
 __all__ = ["FiniteMapOperations", "FiniteMap", "Mapping"]
 
@@ -39,18 +41,10 @@ class FiniteMap(Generic[A, B], Mapping[A, B], ABC):
 
 
 class FiniteMapOperations(ABC):
-    @overload
-    def identity(self, s: FiniteSet[A]) -> FiniteMap[A, A]:
-        ...
-
-    @overload
-    def identity(self, s: Setoid[A]) -> Mapping[A, A]:
-        ...
-
     @abstractmethod
-    def identity(self, s: Setoid[A]) -> Mapping[A, A]:
+    def identity(self, s: FiniteSet[A]) -> FiniteMap[A, A]:
         """Returns the identity on a set."""
 
     @abstractmethod
-    def compose(self, f: FiniteMap[A, B], g: FiniteMap[B, C]) -> FiniteMap[A, C]:
+    def compose(self, f: FiniteMap[E1, E2], g: FiniteMap[E2, E3]) -> FiniteMap[E1, E3]:
         """Compose two functions."""
