@@ -1,11 +1,11 @@
 from __future__ import annotations
 
-from abc import ABC, abstractmethod
+from abc import ABC
 from typing import Any, List
 
 from typing_extensions import TypedDict
 
-from .helper import IOHelper
+from .helper import Serializer
 from .maps import FiniteMap
 from .sets_representation import FiniteSet_desc
 from .types import ConcreteRepr
@@ -22,11 +22,14 @@ class FiniteMap_desc(TypedDict):
     values: List[List[ConcreteRepr]]
 
 
-class FiniteMapRepresentation(ABC):
-    @abstractmethod
-    def load(self, h: IOHelper, s: FiniteMap_desc) -> FiniteMap[Any, Any]:
-        ...
+class FiniteMapRepresentation(Serializer[FiniteMap[Any, Any], FiniteMap_desc], ABC):
+    pass
 
-    @abstractmethod
-    def save(self, h: IOHelper, m: FiniteMap[Any, Any]) -> FiniteMap_desc:
-        ...
+
+# @abstractmethod
+# def load(self, h: IOHelper, s: FiniteMap_desc) -> FiniteMap[Any, Any]:
+#     ...
+#
+# @abstractmethod
+# def save(self, h: IOHelper, m: FiniteMap[Any, Any]) -> FiniteMap_desc:
+#     ...
